<?php
/**
 * Buttons section
 */
Kirki::add_section( 'buttons', array(
	'title'          => esc_attr__( 'Buttons', 'landed' ),
	'priority'       => 15,
	'panel'          => 'appearance'
) );

/**
 * Button text
 */
Kirki::add_field( 'landed_options', array(
	'type'        => 'typography',
	'settings'    => 'btn_text',
	'label'       => esc_attr__( 'Typography', 'landed' ),
	'section'     => 'buttons',
	'default'     => array(
		'font-family'    => 'inherit',
		'variant'        => '600',
		'font-size'      => '14px',
		'line-height'    => '1',
		'letter-spacing' => '0',
		'text-transform' => 'uppercase'
	),
	'output'       => array(
		array(
			'element'  => landed_button_selector()
		),
	),
) );

/**
 * Button color
 */
Kirki::add_field( 'landed_options', array(
	'type'        => 'color',
	'settings'    => 'btn_color',
	'label'       => esc_attr__( 'Color', 'landed' ),
	'section'     => 'buttons',
	'default'     => '#ffffff',
	'choices'     => array(
		'alpha' => true,
	),
	'output'      => array(
		array(
			'element'  => landed_button_selector(),
			'property' => 'color',
			'exclude'  => array( '#ffffff' )
		),
	),
	'transport'   => 'postMessage',
	'js_vars'     => array(
		array(
			'element'  => landed_button_selector(),
			'property' => 'color',
			'function' => 'css',
		),
	),
) );

/**
 * Button color: Hover
 */
Kirki::add_field( 'landed_options', array(
	'type'        => 'color',
	'settings'    => 'btn_color_hover',
	'label'       => esc_attr__( 'Color: Hover', 'landed' ),
	'section'     => 'buttons',
	'default'     => '#ffffff',
	'choices'     => array(
		'alpha' => true,
	),
	'output'      => array(
		array(
			'element'  => implode( ':hover, ', landed_button_selector() ),
			'property' => 'color',
			'exclude'  => array( '#ffffff' )
		),
	),
	'transport'   => 'postMessage',
	'js_vars'     => array(
		array(
			'element'  => implode( ':hover, ', landed_button_selector() ),
			'property' => 'color',
			'function' => 'css',
		),
	),
) );

/**
 * Button background color
 */
Kirki::add_field( 'landed_options', array(
	'type'        => 'color',
	'settings'    => 'btn_bg_color',
	'label'       => esc_attr__( 'Background Color', 'landed' ),
	'section'     => 'buttons',
	'default'     => '#0ca5de',
	'choices'     => array(
		'alpha' => true,
	),
	'output'      => array(
		array(
			'element'  => landed_button_selector(),
			'property' => 'background-color',
			'exclude'  => array( '#0ca5de' )
		),
	),
	'transport'   => 'postMessage',
	'js_vars'     => array(
		array(
			'element'  => landed_button_selector(),
			'property' => 'background-color',
			'function' => 'css',
		),
	),
) );

/**
 * Button background color: Hover
 */
Kirki::add_field( 'landed_options', array(
	'type'        => 'color',
	'settings'    => 'btn_bg_hover',
	'label'       => esc_attr__( 'Background Color: Hover', 'landed' ),
	'section'     => 'buttons',
	'default'     => '#2c2c2c',
	'choices'     => array(
		'alpha' => true,
	),
	'output'      => array(
		array(
			'element'  => implode( ':hover, ', landed_button_selector() ),
			'property' => 'background-color',
			'exclude'  => array( '#2c2c2c' )
		),
	),
	'transport'   => 'postMessage',
	'js_vars'     => array(
		array(
			'element'  => implode( ':hover, ', landed_button_selector() ),
			'property' => 'background-color',
			'function' => 'css',
		),
	),
) );

/**
 * Button height
 */
Kirki::add_field( 'landed_options', array(
	'type'        => 'slider',
	'settings'    => 'btn_height',
	'label'       => esc_attr__( 'Button Height', 'landed' ),
	'description' => esc_attr__( 'Control the padding in pixels above and below your button text.', 'landed' ),
	'section'     => 'buttons',
	'default'     => '14',
	'choices'      => array(
		'min'  => 0,
		'max'  => 30,
		'step' => 1,
	),
	'output'      => array(
		array(
			'element'  => landed_button_selector(),
			'property' => 'padding-top',
			'units'    => 'px',
			'exclude'  => array( '14' )
		),
		array(
			'element'  => landed_button_selector(),
			'property' => 'padding-bottom',
			'units'    => 'px',
			'exclude'  => array( '14' )
		),
	),
	'transport'    => 'postMessage',
	'js_vars'      => array(
		array(
			'element'  => landed_button_selector(),
			'property' => 'padding-top',
			'units'    => 'px',
			'function' => 'css',
		),
		array(
			'element'  => landed_button_selector(),
			'property' => 'padding-bottom',
			'units'    => 'px',
			'function' => 'css',
		),
	),
) );

/**
 * Button width
 */
Kirki::add_field( 'landed_options', array(
	'type'        => 'slider',
	'settings'    => 'btn_width',
	'label'       => esc_attr__( 'Button Width', 'landed' ),
	'description' => esc_attr__( 'Control the padding in pixels to the left and right of your button text.', 'landed' ),
	'section'     => 'buttons',
	'default'     => '20',
	'choices'      => array(
		'min'  => 0,
		'max'  => 50,
		'step' => 1,
	),
	'output'      => array(
		array(
			'element'  => landed_button_selector(),
			'property' => 'padding-left',
			'units'    => 'px',
			'exclude'  => array( '20' )
		),
		array(
			'element'  => landed_button_selector(),
			'property' => 'padding-right',
			'units'    => 'px',
			'exclude'  => array( '20' )
		),
	),
	'transport'    => 'postMessage',
	'js_vars'      => array(
		array(
			'element'  => landed_button_selector(),
			'property' => 'padding-left',
			'units'    => 'px',
			'function' => 'css',
		),
		array(
			'element'  => landed_button_selector(),
			'property' => 'padding-right',
			'units'    => 'px',
			'function' => 'css',
		),
	),
) );

/**
 * Button border radius
 */
Kirki::add_field( 'landed_options', array(
	'type'        => 'slider',
	'settings'    => 'btn_radius',
	'label'       => esc_attr__( 'Button Shape', 'landed' ),
	'description' => esc_attr__( 'Control the shape of the button.', 'landed' ),
	'section'     => 'buttons',
	'default'     => '5',
	'choices'      => array(
		'min'  => 0,
		'max'  => 20,
		'step' => 1,
	),
	'output'      => array(
		array(
			'element'  => landed_button_selector(),
			'property' => 'border-radius',
			'units'    => 'px',
			'exclude'  => array( '5' )
		),
	),
	'transport'    => 'postMessage',
	'js_vars'      => array(
		array(
			'element'  => landed_button_selector(),
			'property' => 'border-radius',
			'units'    => 'px',
			'function' => 'css',
		),
	),
) );
