<?php
/**
 * Header panel
 */
Kirki::add_panel( 'header', array(
	'title'          => esc_attr__( 'Header', 'landed' ),
	'description'    => esc_attr__( 'Customize the header area of the theme.', 'landed' ),
	'priority'       => 140,
) );

/**
 * Header section
 */
Kirki::add_section( 'header_settings', array(
	'title'          => esc_attr__( 'General', 'landed' ),
	'priority'       => 1,
	'panel'          => 'header'
) );

/**
 * Header style
 */
Kirki::add_field( 'landed_options', array(
	'type'        => 'select',
	'settings'    => 'header_style',
	'label'       => esc_attr__( 'Style', 'landed' ),
	'section'     => 'header_settings',
	'default'     => 'default',
	'multiple'    => 1,
	'choices'     => array(
		'default' => esc_attr__( 'Default', 'landed' ),
		'custom'  => esc_attr__( 'Custom Header', 'landed' )
	),
) );

/**
 * Header custom
 */
Kirki::add_field( 'landed_options', array(
	'type'        => 'select',
	'settings'    => 'header_template',
	'label'       => esc_attr__( 'Select Template', 'landed' ),
	'description' => esc_attr__( 'Choose a template created in Appearance > My Library.', 'landed' ),
	'section'     => 'header_settings',
	'default'     => '0',
	'multiple'    => 1,
	'choices'     => landed_library( 'library' ),
	'required'    => array(
		array(
			'setting'  => 'header_style',
			'operator' => '==',
			'value'    => 'custom',
		),
	),
) );

/**
 * Search
 */
Kirki::add_field( 'landed_options', array(
	'type'        => 'toggle',
	'settings'    => 'search_icon',
	'label'       => esc_attr__( 'Search', 'landed' ),
	'description' => esc_attr__( 'Enable search icon in header.', 'landed' ),
	'section'     => 'header_settings',
	'default'     => '1',
	'required'    => array(
		array(
			'setting'  => 'header_style',
			'operator' => '==',
			'value'    => 'default',
		),
	),
) );

/**
 * Shadow
 */
Kirki::add_field( 'landed_options', array(
	'type'        => 'toggle',
	'settings'    => 'header_shadow',
	'label'       => esc_attr__( 'Shadow', 'landed' ),
	'description' => esc_attr__( 'Enable shadow for the header.', 'landed' ),
	'section'     => 'header_settings',
	'default'     => '1',
	'output' => array(
		array(
			'element'       => '.site-header',
			'property'      => 'box-shadow',
			'value_pattern' => '0 0 5px rgba(0, 0, 0, 0.09)',
			'exclude'       => array( false )
		),
	),
	'required'    => array(
		array(
			'setting'  => 'header_style',
			'operator' => '==',
			'value'    => 'default',
		),
	),
) );

/**
 * Sticky
 */
Kirki::add_field( 'landed_options', array(
	'type'        => 'toggle',
	'settings'    => 'header_sticky',
	'label'       => esc_attr__( 'Sticky', 'landed' ),
	'description' => esc_attr__( 'Enable the sticky header.', 'landed' ),
	'section'     => 'header_settings',
	'default'     => '0',
	'output' => array(
		array(
			'element'       => '.site-header',
			'property'      => 'position',
			'media_query'   => '@media (min-width: 768px)',
			'value_pattern' => 'fixed',
			'exclude'       => array( false )
		),
		array(
			'element'       => '.site-header',
			'property'      => 'width',
			'media_query'   => '@media (min-width: 768px)',
			'value_pattern' => '100%',
			'exclude'       => array( false )
		),
		array(
			'element'       => '.site-header',
			'property'      => 'z-index',
			'media_query'   => '@media (min-width: 768px)',
			'value_pattern' => '99',
			'exclude'       => array( false )
		),
		array(
			'element'       => '.site-content',
			'property'      => 'padding-top',
			'media_query'   => '@media (min-width: 768px)',
			'value_pattern' => '16rem',
			'exclude'       => array( false )
		),
	),
	'required'    => array(
		array(
			'setting'  => 'header_style',
			'operator' => '==',
			'value'    => 'default',
		),
	),
) );

/**
 * Height
 */
Kirki::add_field( 'landed_options', array(
	'type'        => 'slider',
	'settings'    => 'header_height',
	'label'       => esc_attr__( 'Height', 'landed' ),
	'description' => esc_attr__( 'Control the height of the header.', 'landed' ),
	'section'     => 'header_settings',
	'default'     => '10',
	'choices'     => array(
		'min'  => '5',
		'max'  => '15',
		'step' => '1',
	),
	'output'      => array(
		array(
			'element'  => '.site-header .container',
			'property' => 'min-height',
			'units'    => 'rem',
			'exclude'  => array( '10' ),
		),
	),
	'transport'   => 'postMessage',
	'js_vars'     => array(
		array(
			'element'  => '.site-header .container',
			'property' => 'min-height',
			'function' => 'css',
			'units'    => 'rem',
		),
	),
	'required'    => array(
		array(
			'setting'  => 'header_style',
			'operator' => '==',
			'value'    => 'default',
		),
	),
) );

/**
 * Background color
 */
Kirki::add_field( 'landed_options', array(
	'type'        => 'color',
	'settings'    => 'header_bg',
	'label'       => esc_attr__( 'Background Color', 'landed' ),
	'section'     => 'header_settings',
	'default'     => '#ffffff',
	'choices'     => array(
		'alpha' => true,
	),
	'output'      => array(
		array(
			'element'  => '.site-header',
			'property' => 'background-color',
			'exclude'  => array( '#ffffff' ),
		),
	),
	'transport'   => 'postMessage',
	'js_vars'     => array(
		array(
			'element'  => '.site-header',
			'property' => 'background-color',
			'function' => 'css',
		),
	),
	'required'    => array(
		array(
			'setting'  => 'header_style',
			'operator' => '==',
			'value'    => 'default',
		),
	),
) );

/**
 * Search color
 */
Kirki::add_field( 'landed_options', array(
	'type'        => 'color',
	'settings'    => 'search_color',
	'label'       => esc_attr__( 'Search Icon Color', 'landed' ),
	'section'     => 'header_settings',
	'default'     => '#414141',
	'choices'     => array(
		'alpha' => true,
	),
	'output'      => array(
		array(
			'element'  => '.search-icon .search-toggle',
			'property' => 'color',
			'exclude'  => array( '#414141' ),
		),
	),
	'transport'   => 'postMessage',
	'js_vars'     => array(
		array(
			'element'  => '.search-icon .search-toggle',
			'property' => 'color',
			'function' => 'css',
		),
	),
	'required'    => array(
		array(
			'setting'  => 'header_style',
			'operator' => '==',
			'value'    => 'default',
		),
		array(
			'setting'  => 'search_icon',
			'operator' => '==',
			'value'    => '1',
		),
	),
) );
